@@ -90,9 +90,20 @@ class SolveTffExperiment(Experiment):
     suffix : str
         Suffix that is appended to the name of the experiment, useful to
         save results in a specific folder.
+    keep_eigenvectors : 'all' or list
+        Use this parameter to remove eigenvectors from
+        `GabMulTff` object after computing performance in order to save
+        space. In this case, the `GabMulTff` will not be usable anymore
+        after the computation of the performance results.
+        If 'all', all eigenvectors are kept. To keep only some eigenvectors,
+        set this parameter to the list of task IDs for which eigenvectors
+        should be kept (usefull if you want to use or plot some task data
+        after the experiments, e.g., using method `plot_task`). If the list
+        is empty, all eigenvectors will be removed.
     """
 
-    def __init__(self, force_reset=False, suffix=''):
+    def __init__(self, force_reset=False, suffix='',
+                 keep_eigenvectors='all'):
         Experiment.__init__(self,
                             name='SolveTffExperiment' + suffix,
                             get_data=get_data,
@@ -105,6 +116,7 @@ class SolveTffExperiment(Experiment):
         self.fig_dir = self.xp_path / 'figures'
         # a little trick to save collections when computing performance
         self.measure = lambda **x: perf_measures(**x, exp=self)
+        self.keep_eigenvectors = keep_eigenvectors
 
     @property
     def n_tasks(self):
@@ -118,7 +130,8 @@ class SolveTffExperiment(Experiment):
         return len(list((self.xp_path / 'tasks').glob('0*')))
 
     @staticmethod
-    def get_experiment(setting='full', force_reset=False):
+    def get_experiment(setting='full', force_reset=False,
+                       keep_eigenvectors=None):
         """
         Get the experiment instance with default values in order to handle it.
 
@@ -133,6 +146,9 @@ class SolveTffExperiment(Experiment):
             If true, reset the experiment by erasing all previous results
             in order to run it from scratch. If False, the existing results are
             kept in order to proceed with the existing experiment.
+        keep_eigenvectors = 'all' or list
+            See constructor of  `SolveTffExperiment`. If None, default
+            values are used.
 
         Returns
         -------
@@ -156,7 +172,9 @@ class SolveTffExperiment(Experiment):
         solver_params = dict(tol_subregions=[None, 1e-5],
                              tolerance_arrf=1e-3,
                              proba_arrf=1 - 1e-4,
-                             rand_state=0)
+                             rand_state=np.arange(10))
+
+        keep_eigenvectors = []
         if setting == 'light':
             data_params['loc_source'] = 'bird'
             data_params['wideband_src'] = 'car'
@@ -166,11 +184,14 @@ class SolveTffExperiment(Experiment):
             problem_params['wb_to_loc_ratio_db'] = 16
             solver_params['tolerance_arrf'] = 1e-2
             solver_params['proba_arrf'] = 1 - 1e-2
+            keep_eigenvectors = [0, 1]
+
 
         # Create Experiment
         suffix = '' if setting == 'full' else '_Light'
         exp = SolveTffExperiment(force_reset=force_reset,
-                                 suffix=suffix)
+                                 suffix=suffix,
+                                 keep_eigenvectors=keep_eigenvectors)
         exp.add_tasks(data_params=data_params,
                       problem_params=problem_params,
                       solver_params=solver_params)
@@ -254,7 +275,8 @@ class SolveTffExperiment(Experiment):
         self.fig_dir.mkdir(parents=True, exist_ok=True)
         print('Figures saved in {}'.format(self.fig_dir))
         results = self.load_results(array_type='xarray')
-        results = results.squeeze()
+        results_std = results.std('solver_rand_state').squeeze()
+        results = results.mean('solver_rand_state').squeeze()
         coords_dict = results.to_dict()['coords']
         csv_path = self.fig_dir / 'exp_solve_pd.csv'
         results.to_series().to_csv(csv_path, header=True)
@@ -304,12 +326,24 @@ class SolveTffExperiment(Experiment):
 
         x = x.reshape(-1)
         y = y.reshape(-1)
+        I = np.logical_and(x!=0, y!=0)
+        x, y = x[I], y[I]
         slope, intercept, r_value, p_value, std_err = linregress(x, y)
-        print('Running times (all): slope={}, intercept={}, 1/slope={},'
-              .format(slope, intercept, 1 / slope))
+        print('Running times (all): slope={}, intercept={}, 1/slope={}, '
+              'r_value={}, p_value={}, std_err={}'
+              .format(slope, intercept, 1 / slope, r_value, p_value, std_err))
         print('Linear slope (not affine):')
         print(np.vdot(x, y) / np.vdot(x, x), np.vdot(x, x) / np.vdot(x, y))
 
+        log_x, log_y = np.log10(x), np.log10(y)
+        slope, intercept, r_value, p_value, std_err = linregress(log_x, log_y)
+        print('Running times (all-log): slope={}, intercept={}, 1/slope={},'
+              'r_value={}, p_value={}, std_err={}'
+              .format(slope, intercept, 1 / slope, r_value, p_value, std_err))
+        print('Linear slope (not affine) - log:')
+        print(np.vdot(log_x, log_y) / np.vdot(log_x, log_x),
+              np.vdot(log_x, log_x) / np.vdot(log_x, log_y))
+
         # plt.plot(x, slope * x + intercept)
         plt.xlabel(r'Running time for TFF-1 (s)')
         plt.ylabel(r'Running time for TFF-P (s)')
@@ -645,6 +679,12 @@ class SolveTffExperiment(Experiment):
         plt.tight_layout()
         plt.savefig(fig_dir / 'spectrogram_true_wb_source.pdf')
 
+    def get_idt_from_params(self, data_params, problem_params, solver_params):
+        d = self.get_task_data_by_params(data_params=data_params,
+                                         problem_params=problem_params,
+                                         solver_params=solver_params)
+        return d['id_task']
+
 
 def get_data(loc_source, wideband_src):
     """
@@ -959,6 +999,11 @@ def perf_measures(task_params, source_data, problem_data,
                     rank_sum=np.sum([s.size for s in gmtff.s_vec_list]),
                     lowest_sv=np.min([np.min(s) for s in gmtff.s_vec_list])
                     )
+    idt = exp.get_idt_from_params(**task_params)
+    if exp.keep_eigenvectors != 'all' and idt not in exp.keep_eigenvectors:
+        sd = exp._read_item(type_item='solved_data', idt=idt)
+        sd['gmtff'].u_mat_list = [None for _ in sd['gmtff'].u_mat_list]
+        exp._write_item(type_item='solved_data', idt=idt, content=sd)
     return dict(**running_times, **sdr_res, **is_res, **features)
 
 
